============
Installation
============

At the command line::

    $ pip install amadeus

Or::

	$ easy_install amadeus

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv amadeus
    $ pip install amadeus
